extensions [gis]
globals [sprengel disclu81 disclu91 disclu01 num_redpatches num_greenpatches num_yellowpatches num_violetpatches num_graypatches num_bluepatches
         cluster_redpatches cluster_greenpatches cluster_yellowpatches cluster_violetpatches cluster_graypatches cluster_bluepatches
         cluster_redagents cluster_greenagents cluster_yellowagents cluster_violetagents cluster_grayagents cluster_blueagents time
         cluster_redagents1 cluster_greenagents1 cluster_yellowagents1 cluster_violetagents1 cluster_grayagents1 cluster_blueagents1
         redp greenp yellowp violetp grayp bluep share_red share_green share_yellow share_violet share_gray share_blue num_patches
         redsh greensh yellowsh violetsh graysh bluesh
         red1agents red2agents red3agents red4agents green1agents green2agents green3agents green4agents yellow1agents yellow2agents
         violet1agents violet2agents violet3agents gray1agents gray2agents gray3agents blue1agents blue2agents blue3agents
         num_radclu red_clu]
         
breed [red1]
breed [red2]
breed [red3]
breed [red4]
breed [green1]
breed [green2]
breed [green3]
breed [green4]
breed [yellow1]
breed [yellow2]
breed [violet1]
breed [violet2]
breed [violet3]
breed [gray1]
breed [gray2]
breed [gray3]
breed [blue1]
breed [blue2]
breed [blue3]
;;19 different agents according to the subcluster variety based on the data of 1981

patches-own [clu_81 subclu_81 clu_91 subclu_91 clu_01 subclu_01] 
;;disclu = district clusters for 1981, 1991 and 2001; variable which represents the six clusters in patch style
;;dissubclu = district subclusters for 1981, 1991 and 2001; variable which represents the sublusters within the six clusters 

turtles-own [hs in ci ss xc yc dissim-total dissim-location dissim-agents similar-nearby other-nearby total-nearby simagents-nearby othagents-nearby totagents-nearby
             similar-nearbynew other-nearbynew total-nearbynew dissim-locationnew] 
;; hs = household size; in = income (for rent); ci = citizenship; ss = social status; similar-nearby = similar patches within radius 'radsim'
;; other-nearby = distinct patches within radius 'radsim'; total-nearby = sum of similar-nearby and other-nearby;
;; simagents-nearby = similar agents within radius 'radsim'; othagents-nearby = other agents within radius 'radsim'; totagents-nearby = sum of simagents-nearby and othagents-nearby

to setup
  clear-turtles
  clear-patches
  clear-drawing
  clear-all-plots
  clear-output
  reset-ticks
  
  ask patches [set pcolor 9]
  gis:set-transformation (list -180 180 -90 90) (list min-pxcor max-pxcor min-pycor max-pycor)
     
  set sprengel gis:load-dataset "sbgdata/sprengel.shp" ;;this layer represents large-scale differentitation of the city area
  set disclu81 gis:load-dataset "sbgdata/cityDistrict_81.shp" ;;this layer represents the six clusters of 1981
  set disclu91 gis:load-dataset "sbgdata/cityDistrict_91.shp" ;;this layer represents the six clusters of 1991
  set disclu01 gis:load-dataset "sbgdata/cityDistrict_01.shp" ;;this layer represents the six clusters of 2001
    
  gis:set-world-envelope (gis:envelope-union-of (gis:envelope-of disclu81) (gis:envelope-of disclu91) (gis:envelope-of disclu01) (gis:envelope-of sprengel))
  
  set time 0
  
end

;;drawing polygon data from the cluster shapefile
to display-district
  gis:set-drawing-color black
  gis:draw disclu81 3
end

;;drawing polygon data from the sprengel shapefile
to display-sprengel
  gis:set-drawing-color black
  gis:draw sprengel 2
end

;;------------------------------------ The 1981 data ----------------------------------------------------------------

;;Using gis:apply-coverage to copy the six cluster values from the cityDistrict_81.dbf dataset to a patch variable
to display-cluster1981
  gis:apply-coverage disclu81 "cluster" clu_81
  ask patches [if (clu_81 = 1) [set pcolor 15] ;;cluster 1 in red
              if (clu_81 = 2) [set pcolor 55] ;;cluster 2 in green
              if (clu_81 = 3) [set pcolor 45] ;;cluster 3 in yellow
              if (clu_81 = 4) [set pcolor 115] ;;cluster 4 in purple
              if (clu_81 = 5) [set pcolor 35] ;;cluster 5 in brown
              if (clu_81 = 6) [set pcolor 105]] ;;cluster 6 in blue
end

;;Using gis:apply-coverage to copy the subcluster values from the cityDistrict_81b.dbf dataset to a patch variable
to display-subcluster1981
  gis:apply-coverage disclu81 "subclua" subclu_81
  ask patches [if (subclu_81 = 111) [set pcolor 18] ;;cluster 111 in light red
              if (subclu_81 = 112) [set pcolor 16] ;;cluster 112 in red
              if (subclu_81 = 113) [set pcolor 14] ;;cluster 113 in dark red
              if (subclu_81 = 114) [set pcolor 12] ;;cluster 114 in dark red
              if (subclu_81 = 211) [set pcolor 58] ;;cluster 211 in light green
              if (subclu_81 = 212) [set pcolor 56] ;;cluster 212 in green
              if (subclu_81 = 213) [set pcolor 54] ;;cluster 213 in dark green
              if (subclu_81 = 214) [set pcolor 52] ;;cluster 214 in dark green
              if (subclu_81 = 311) [set pcolor 49] ;;cluster 311 in light yellow
              if (subclu_81 = 312) [set pcolor 47] ;;cluster 312 in yellow
              if (subclu_81 = 411) [set pcolor 119] ;;cluster 411 in light purple
              if (subclu_81 = 412) [set pcolor 117] ;;cluster 412 in light purple
              if (subclu_81 = 413) [set pcolor 115] ;;cluster 413 in purple
              if (subclu_81 = 511) [set pcolor 8] ;;cluster 511 in light gray
              if (subclu_81 = 512) [set pcolor 6] ;;cluster 512 in gray
              if (subclu_81 = 513) [set pcolor 4] ;;cluster 513 in dark gray
              if (subclu_81 = 611) [set pcolor 108] ;;cluster 611 in light blue
              if (subclu_81 = 612) [set pcolor 106] ;;cluster 612 in blue
              if (subclu_81 = 613) [set pcolor 104]] ;;cluster 613 in dark blue
end


;;-------------------------------------- The 1991 data --------------------------------------------------------------

;;Using gis:apply-coverage to copy the six cluster values from the cityDistrict_91.dbf dataset to a patch variable
to display-cluster1991
  gis:apply-coverage disclu91 "cluster" clu_91
  ask patches [if (clu_91 = 2) [set pcolor 55] ;;cluster 2 in green
              if (clu_91 = 3) [set pcolor 45] ;;cluster 3 in yellow
              if (clu_91 = 4) [set pcolor 115] ;;cluster 4 in purple
              if (clu_91 = 5) [set pcolor 5] ;;cluster 5 in gray
              if (clu_91 = 6) [set pcolor 105] ;;cluster 6 in blue
              if (clu_91 = 7) [set pcolor 135]] ;;cluster 7 in pink
end

;;Using gis:apply-coverage to copy the subcluster values from the cityDistrict_91b.dbf dataset to a patch variable
to display-subcluster1991
  gis:apply-coverage disclu91 "subclua" subclu_91
  ask patches [if (subclu_91 = 211) [set pcolor 58] ;;cluster 211 in light green
              if (subclu_91 = 212) [set pcolor 56] ;;cluster 212 in green
              if (subclu_91 = 213) [set pcolor 54] ;;cluster 213 in dark green
              if (subclu_91 = 214) [set pcolor 52] ;;cluster 214 in dark green
              if (subclu_91 = 311) [set pcolor 49] ;;cluster 311 in light yellow
              if (subclu_91 = 312) [set pcolor 47] ;;cluster 312 in yellow
              if (subclu_91 = 411) [set pcolor 119] ;;cluster 411 in light purple
              if (subclu_91 = 412) [set pcolor 117] ;;cluster 412 in purple
              if (subclu_91 = 413) [set pcolor 115] ;;cluster 413 in dark purple
              if (subclu_91 = 511) [set pcolor 8] ;;cluster 511 in light gray
              if (subclu_91 = 512) [set pcolor 6] ;;cluster 512 in gray
              if (subclu_91 = 513) [set pcolor 4] ;;cluster 113 in dark gray
              if (subclu_91 = 611) [set pcolor 108] ;;cluster 611 in light blue
              if (subclu_91 = 612) [set pcolor 107] ;;cluster 612 in blue
              if (subclu_91 = 613) [set pcolor 106] ;;cluster 612 in blue
              if (subclu_91 = 614) [set pcolor 105] ;;cluster 614 in dark blue
              if (subclu_91 = 615) [set pcolor 104] ;;cluster 615 in dark blue
              if (subclu_91 = 711) [set pcolor 137] ;;cluster 711 in light pink
              if (subclu_91 = 712) [set pcolor 135]] ;;cluster 712 in pink
end


;;------------------------------------------- The 2001 data --------------------------------------------------------

;;Using gis:apply-coverage to copy the six cluster values from the cityDistrict_01.dbf dataset to a patch variable
to display-cluster2001
  gis:apply-coverage disclu01 "cluster" clu_01
  ask patches [if (clu_01 = 1) [set pcolor 15] ;;cluster 1 in red
              if (clu_01 = 2) [set pcolor 55] ;;cluster 2 in green
              if (clu_01 = 3) [set pcolor 45] ;;cluster 3 in yellow
              if (clu_01 = 5) [set pcolor 5] ;;cluster 5 in gray
              if (clu_01 = 6) [set pcolor 105] ;;cluster 6 in blue
              if (clu_01 = 8) [set pcolor 35]] ;;cluster 8 in brown
end

;;Using gis:apply-coverage to copy the subcluster values from the cityDistrict_01b.dbf dataset to a patch variable
to display-subcluster2001
  gis:apply-coverage disclu01 "subclua" subclu_01
  ask patches [if (subclu_01 = 211) [set pcolor 58] ;;cluster 211 in light green
              if (subclu_01 = 212) [set pcolor 56] ;;cluster 212 in green
              if (subclu_01 = 213) [set pcolor 54] ;;cluster 213 in dark green
              if (subclu_01 = 214) [set pcolor 52] ;;cluster 214 in dark green
              if (subclu_01 = 311) [set pcolor 49] ;;cluster 311 in light yellow
              if (subclu_01 = 312) [set pcolor 47] ;;cluster 312 in yellow
              if (subclu_01 = 411) [set pcolor 119] ;;cluster 411 in light purple
              if (subclu_01 = 412) [set pcolor 117] ;;cluster 412 in purple
              if (subclu_01 = 413) [set pcolor 115] ;;cluster 413 in dark purple
              if (subclu_01 = 511) [set pcolor 8] ;;cluster 511 in light gray
              if (subclu_01 = 512) [set pcolor 6] ;;cluster 512 in gray
              if (subclu_01 = 513) [set pcolor 4] ;;cluster 113 in dark gray
              if (subclu_01 = 611) [set pcolor 108] ;;cluster 611 in light blue
              if (subclu_01 = 612) [set pcolor 107] ;;cluster 612 in blue
              if (subclu_01 = 613) [set pcolor 106] ;;cluster 612 in blue
              if (subclu_01 = 614) [set pcolor 105] ;;cluster 614 in dark blue
              if (subclu_01 = 615) [set pcolor 104] ;;cluster 615 in dark blue
              if (subclu_01 = 711) [set pcolor 137] ;;cluster 711 in light pink
              if (subclu_01 = 712) [set pcolor 135]] ;;cluster 712 in pink
end

;;---------------------------------------------- The creation of a patch and agent sample -------------------------------------------------------------------------

;;creates a sample of agents based on the 1981 data
to create-sample
  ask patches [if pcolor = 18 or pcolor = 16 or pcolor = 14 or pcolor = 12 [set pcolor 72]
               if pcolor = 72 [if (random 101) < densityRedAgentsD [set pcolor 12 + (random 7)] 
                              if (random 101) < densityGreenAgentsF [set pcolor 52 + (random 7)]
                              if (random 101) < densityYellowAgentsF [set pcolor 47 + (random 3)]
                              if (random 101) < densityPurpleAgentsF [set pcolor 115 + (random 5)]
                              if (random 101) < densityGrayAgentsF [set pcolor 4 + (random 5)]
                              if (random 101) < densityBlueAgentsF [set pcolor 104 + (random 5)]]] ;;creates a sample for red agents, based on an initial background color value of 72
  ask patches [if pcolor = 58 or pcolor = 56 or pcolor = 54 or pcolor = 52 [set pcolor 73]
               if pcolor = 73 [if (random 101) < densityGreenAgentsD [set pcolor 52 + (random 7)] 
                              if (random 101) < densityRedAgentsF [set pcolor 12 + (random 7)]
                              if (random 101) < densityYellowAgentsF [set pcolor 47 + (random 3)]
                              if (random 101) < densityPurpleAgentsF [set pcolor 115 + (random 5)]
                              if (random 101) < densityGrayAgentsF [set pcolor 4 + (random 5)]
                              if (random 101) < densityBlueAgentsF [set pcolor 104 + (random 5)]]] ;;creates a sample for green agents, based on an initial background color value of 73
  ask patches [if pcolor = 49 or pcolor = 47 [set pcolor 74]
               if pcolor = 74 [if (random 101) < densityYellowAgentsD [set pcolor 47 + (random 3)] 
                              if (random 101) < densityRedAgentsF [set pcolor 12 + (random 7)]
                              if (random 101) < densityGreenAgentsF [set pcolor 52 + (random 7)]
                              if (random 101) < densityPurpleAgentsF [set pcolor 115 + (random 5)]
                              if (random 101) < densityGrayAgentsF [set pcolor 4 + (random 5)]
                              if (random 101) < densityBlueAgentsF [set pcolor 104 + (random 5)]]] ;;creates a sample for yellow agents, based on an initial background color value of 74
  ask patches [if pcolor = 119 or pcolor = 117 or pcolor = 115 [set pcolor 75]
               if pcolor = 75 [if (random 101) < densityPurpleAgentsD [set pcolor 115 + (random 5)] 
                              if (random 101) < densityRedAgentsF [set pcolor 12 + (random 7)]
                              if (random 101) < densityYellowAgentsF [set pcolor 47 + (random 3)]
                              if (random 101) < densityGreenAgentsF [set pcolor 52 + (random 7)]
                              if (random 101) < densityGrayAgentsF [set pcolor 4 + (random 5)]
                              if (random 101) < densityBlueAgentsF [set pcolor 104 + (random 5)]]] ;;creates a sample for purple agents, based on an initial background color value of 75
  ask patches [if pcolor = 8 or pcolor = 6 or pcolor = 4 [set pcolor 76]
               if pcolor = 76 [if (random 101) < densityGrayAgentsD [set pcolor 4 + (random 5)] 
                              if (random 101) < densityRedAgentsF [set pcolor 12 + (random 7)]
                              if (random 101) < densityYellowAgentsF [set pcolor 47 + (random 3)]
                              if (random 101) < densityPurpleAgentsF [set pcolor 115 + (random 5)]
                              if (random 101) < densityGreenAgentsF [set pcolor 52 + (random 7)]
                              if (random 101) < densityBlueAgentsF [set pcolor 104 + (random 5)]]] ;;creates a sample for gray agents, based on an initial background color value of 76
  ask patches [if pcolor = 108 or pcolor = 106 or pcolor = 104 [set pcolor 77]
               if pcolor = 77 [if (random 101) < densityBlueAgentsD [set pcolor 104 + (random 5)] 
                              if (random 101) < densityRedAgentsF [set pcolor 12 + (random 7)]
                              if (random 101) < densityYellowAgentsF [set pcolor 47 + (random 3)]
                              if (random 101) < densityPurpleAgentsF [set pcolor 115 + (random 5)]
                              if (random 101) < densityGrayAgentsF [set pcolor 4 + (random 5)]
                              if (random 101) < densityGreenAgentsF [set pcolor 52 + (random 7)]]] ;;creates a sample for blue agents, based on an initial background color value of 77                      

end

to create-agents
  ask patches [if pcolor = 18 [sprout 1 [set breed red1 set xc xcor set yc ycor set color 18 set size 1 set hs 3 set in 2 set ss 1 ifelse (random 100) < 15 [set ci 2] [set ci 1]]]]
  ask patches [if pcolor = 16 [sprout 1 [set breed red2 set xc xcor set yc ycor set color 16 set size 1 set hs 1 set in 3 set ss 2 ifelse (random 100) < 11 [set ci 2] [set ci 1]]]]
  ask patches [if pcolor = 14 [sprout 1 [set breed red3 set xc xcor set yc ycor set color 14 set size 1 set hs 1 set in 3 set ss 2 ifelse (random 100) < 6 [set ci 2] [set ci 1]]]]
  ask patches [if pcolor = 12 [sprout 1 [set breed red4 set xc xcor set yc ycor set color 12 set size 1 set hs 1 set in 3 set ss 3 ifelse (random 100) < 8 [set ci 2] [set ci 1]]]]
  ask patches [if pcolor = 58 [sprout 1 [set breed green1 set xc xcor set yc ycor set color 58 set size 1 set hs 3 set in 1 set ss 1 ifelse (random 100) < 6 [set ci 2] [set ci 1]]]]
  ask patches [if pcolor = 56 [sprout 1 [set breed green2 set xc xcor set yc ycor set color 56 set size 1 set hs 2 set in 1 set ss 1 ifelse (random 100) < 4 [set ci 2] [set ci 1]]]]
  ask patches [if pcolor = 54 [sprout 1 [set breed green3 set xc xcor set yc ycor set color 54 set size 1 set hs 1 set in 3 set ss 3 ifelse (random 100) < 15 [set ci 2] [set ci 1]]]]
  ask patches [if pcolor = 52 [sprout 1 [set breed green4 set xc xcor set yc ycor set color 52 set size 1 set hs 1 set in 3 set ss 3 ifelse (random 100) < 6 [set ci 2] [set ci 1]]]]
  ask patches [if pcolor = 49 [sprout 1 [set breed yellow1 set xc xcor set yc ycor set color 49 set size 1 set hs 3 set in 3 set ss 4 ifelse (random 100) < 7 [set ci 2] [set ci 1]]]]
  ask patches [if pcolor = 47 [sprout 1 [set breed yellow2 set xc xcor set yc ycor set color 47 set size 1 set hs 5 set in 2 set ss 3 ifelse (random 100) < 5 [set ci 2] [set ci 1]]]]
  ask patches [if pcolor = 119 [sprout 1 [set breed violet1 set xc xcor set yc ycor set color 119 set size 1 set hs 4 set in 3 set ss 3 ifelse (random 100) < 11 [set ci 2] [set ci 1]]]]
  ask patches [if pcolor = 117 [sprout 1 [set breed violet2 set xc xcor set yc ycor set color 117 set size 1 set hs 5 set in 4 set ss 3 ifelse (random 100) < 7 [set ci 2] [set ci 1]]]]
  ask patches [if pcolor = 115 [sprout 1 [set breed violet3 set xc xcor set yc ycor set color 115 set size 1 set hs 5 set in 4 set ss 2 ifelse (random 100) < 11 [set ci 2] [set ci 1]]]]
  ask patches [if pcolor = 8 [sprout 1 [set breed gray1 set xc xcor set yc ycor set color 8 set size 1 set hs 3 set in 5 set ss 3 ifelse (random 100) < 14 [set ci 2] [set ci 1]]]]
  ask patches [if pcolor = 6 [sprout 1 [set breed gray2 set xc xcor set yc ycor set color 6 set size 1 set hs 3 set in 5 set ss 3 ifelse (random 100) < 10 [set ci 2] [set ci 1]]]]
  ask patches [if pcolor = 4 [sprout 1 [set breed gray3 set xc xcor set yc ycor set color 4 set size 1 set hs 2 set in 5 set ss 4 ifelse (random 100) < 14 [set ci 2] [set ci 1]]]]
  ask patches [if pcolor = 108 [sprout 1 [set breed blue1 set xc xcor set yc ycor set color 108 set size 1 set hs 3 set in 2 set ss 5 ifelse (random 100) < 9 [set ci 2] [set ci 1]]]]
  ask patches [if pcolor = 106 [sprout 1 [set breed blue2 set xc xcor set yc ycor set color 106 set size 1 set hs 3 set in 1 set ss 5 ifelse (random 100) < 7 [set ci 2] [set ci 1]]]]
  ask patches [if pcolor = 104 [sprout 1 [set breed blue3 set xc xcor set yc ycor set color 104 set size 1 set hs 4 set in 3 set ss 5 ifelse (random 100) < 10 [set ci 2] [set ci 1]]]] 
end 

;;---------------------------------------------- The segregation process -------------------------------------------------------------------------

to identify-neighborpatches
  ask red1 [set similar-nearby count (patches in-radius radsim) with [(pcolor = 18) or (pcolor = 16) or (pcolor = 14) or (pcolor = 58) or (pcolor = 56)]
            set other-nearby count (patches in-radius radsim) with [(pcolor != 18) or (pcolor != 16) or (pcolor != 14) or (pcolor != 58) or (pcolor != 56)]
            set total-nearby similar-nearby + other-nearby]
  ask red2 [set similar-nearby count (patches in-radius radsim) with [(pcolor = 16) or (pcolor = 14) or (pcolor = 12) or (pcolor = 54) or (pcolor = 52) or (pcolor = 47) or (pcolor = 119) or (pcolor = 117) or (pcolor = 115)]
            set other-nearby count (patches in-radius radsim) with [(pcolor != 16) or (pcolor != 14) or (pcolor != 12) or (pcolor != 54) or (pcolor != 52) or (pcolor != 47) or (pcolor != 119) or (pcolor != 117) or (pcolor != 115)]
            set total-nearby similar-nearby + other-nearby]
  ask red3 [set similar-nearby count (patches in-radius radsim) with [(pcolor = 16) or (pcolor = 14) or (pcolor = 12) or (pcolor = 54) or (pcolor = 52) or (pcolor = 47) or (pcolor = 119) or (pcolor = 117) or (pcolor = 115)]
            set other-nearby count (patches in-radius radsim) with [(pcolor != 16) or (pcolor != 14) or (pcolor != 12) or (pcolor != 54) or (pcolor != 52) or (pcolor != 47) or (pcolor != 119) or (pcolor != 117) or (pcolor != 115)]
            set total-nearby similar-nearby + other-nearby]
  ask red4 [set similar-nearby count (patches in-radius radsim) with [(pcolor = 12) or (pcolor = 54) or (pcolor = 52) or (pcolor = 49) or (pcolor = 119) or (pcolor = 117) or (pcolor = 115)]
            set other-nearby count (patches in-radius radsim) with [(pcolor != 12) or (pcolor != 54) or (pcolor != 52) or (pcolor != 49) or (pcolor != 119) or (pcolor != 117) or (pcolor != 115)]
            set total-nearby similar-nearby + other-nearby]
            
  ask green1 [set similar-nearby count (patches in-radius radsim) with [(pcolor = 58) or (pcolor = 56) or (pcolor = 18)]
              set other-nearby count (patches in-radius radsim) with [(pcolor != 58) or (pcolor != 56) or (pcolor != 18)]
              set total-nearby similar-nearby + other-nearby]
  ask green2 [set similar-nearby count (patches in-radius radsim) with [(pcolor = 58) or (pcolor = 56) or (pcolor = 18)]
              set other-nearby count (patches in-radius radsim) with [(pcolor != 58) or (pcolor != 56) or (pcolor != 18)]
              set total-nearby similar-nearby + other-nearby]
  ask green3 [set similar-nearby count (patches in-radius radsim) with [(pcolor = 54) or (pcolor = 52) or (pcolor = 12) or (pcolor = 49) or (pcolor = 47) or (pcolor = 119) or (pcolor = 117) or (pcolor = 115)]
              set other-nearby count (patches in-radius radsim) with [(pcolor != 54) or (pcolor != 52) or (pcolor != 12) or (pcolor != 49) or (pcolor != 47) or (pcolor != 119) or (pcolor != 117) or (pcolor != 115)]
              set total-nearby similar-nearby + other-nearby]
  ask green4 [set similar-nearby count (patches in-radius radsim) with [(pcolor = 54) or (pcolor = 52) or (pcolor = 12) or (pcolor = 49) or (pcolor = 47) or (pcolor = 119) or (pcolor = 117) or (pcolor = 115)]
              set other-nearby count (patches in-radius radsim) with [(pcolor != 54) or (pcolor != 52) or (pcolor != 12) or (pcolor != 49) or (pcolor != 47) or (pcolor != 119) or (pcolor != 117) or (pcolor != 115)]
              set total-nearby similar-nearby + other-nearby]
            
  ask yellow1 [set similar-nearby count (patches in-radius radsim) with [(pcolor = 49) or (pcolor = 104)]
               set other-nearby count (patches in-radius radsim) with [(pcolor != 49) or (pcolor != 104)]
               set total-nearby similar-nearby + other-nearby]
  ask yellow2 [set similar-nearby count (patches in-radius radsim) with [(pcolor = 12) or (pcolor = 49) or (pcolor = 47) or (pcolor = 54) or (pcolor = 52) or (pcolor = 119)]
               set other-nearby count (patches in-radius radsim) with [(pcolor != 12) or (pcolor != 49) or (pcolor != 47) or (pcolor != 54) or (pcolor != 52) or (pcolor != 119)]
               set total-nearby similar-nearby + other-nearby]
            
  ask violet1 [set similar-nearby count (patches in-radius radsim) with [(pcolor = 54) or (pcolor = 52) or (pcolor = 12) or (pcolor = 49) or (pcolor = 47) or (pcolor = 119) or (pcolor = 117)]
               set other-nearby count (patches in-radius radsim) with [(pcolor != 54) or (pcolor != 52) or (pcolor != 12) or (pcolor != 49) or (pcolor != 47) or (pcolor != 119) or (pcolor != 117)]
               set total-nearby similar-nearby + other-nearby]
  ask violet2 [set similar-nearby count (patches in-radius radsim) with [(pcolor = 54) or (pcolor = 52) or (pcolor = 12) or (pcolor = 49) or (pcolor = 8) or (pcolor = 6) or (pcolor = 4) or (pcolor = 119) or (pcolor = 117)]
               set other-nearby count (patches in-radius radsim) with [(pcolor != 54) or (pcolor != 52) or (pcolor != 12) or (pcolor != 49) or (pcolor != 8) or (pcolor != 6) or (pcolor != 4) or (pcolor != 119) or (pcolor != 117)]
               set total-nearby similar-nearby + other-nearby]
  ask violet3 [set similar-nearby count (patches in-radius radsim) with [(pcolor = 54) or (pcolor = 52) or (pcolor = 12) or (pcolor = 16) or (pcolor = 14) or (pcolor = 8) or (pcolor = 6) or (pcolor = 115) or (pcolor = 119) or (pcolor = 117)]
               set other-nearby count (patches in-radius radsim) with [(pcolor != 54) or (pcolor != 52) or (pcolor != 12) or (pcolor != 16) or (pcolor != 14) or (pcolor != 8) or (pcolor != 6) or (pcolor != 115) or (pcolor != 119) or (pcolor != 117)]
               set total-nearby similar-nearby + other-nearby]
            
  ask gray1 [set similar-nearby count (patches in-radius radsim) with [(pcolor = 8) or (pcolor = 49) or (pcolor = 117) or (pcolor = 6) or (pcolor = 4)]
             set other-nearby count (patches in-radius radsim) with [(pcolor != 8) or (pcolor != 49) or (pcolor != 117) or (pcolor != 6) or (pcolor != 4)]
             set total-nearby similar-nearby + other-nearby]
  ask gray2 [set similar-nearby count (patches in-radius radsim) with [(pcolor = 8) or (pcolor = 49) or (pcolor = 117) or (pcolor = 6) or (pcolor = 4)]
             set other-nearby count (patches in-radius radsim) with [(pcolor != 8) or (pcolor != 49) or (pcolor != 117) or (pcolor != 6) or (pcolor != 4)]
             set total-nearby similar-nearby + other-nearby]
  ask gray3 [set similar-nearby count (patches in-radius radsim) with [(pcolor = 4) or (pcolor = 49) or (pcolor = 104)]
             set other-nearby count (patches in-radius radsim) with [(pcolor != 4) or (pcolor != 49) or (pcolor != 104)]
             set total-nearby similar-nearby + other-nearby]
            
  ask blue1 [set similar-nearby count (patches in-radius radsim) with [(pcolor = 108) or (pcolor = 106) or (pcolor = 104)]
             set other-nearby count (patches in-radius radsim) with [(pcolor != 108) or (pcolor != 106) or (pcolor != 104)]
             set total-nearby similar-nearby + other-nearby]
  ask blue2 [set similar-nearby count (patches in-radius radsim) with [(pcolor = 108) or (pcolor = 106) or (pcolor = 104)]
             set other-nearby count (patches in-radius radsim) with [(pcolor != 108) or (pcolor != 106) or (pcolor != 104)]
             set total-nearby similar-nearby + other-nearby]
  ask blue3 [set similar-nearby count (patches in-radius radsim) with [(pcolor = 108) or (pcolor = 106) or (pcolor = 104)]
             set other-nearby count (patches in-radius radsim) with [(pcolor != 108) or (pcolor != 106) or (pcolor != 104)]
             set total-nearby similar-nearby + other-nearby]
end 

to identify-neighboragents
  ;;the first line calculates the similarity between an agent and its neighbors with regard to social status (variable is 'ss')
  ;;the second line calculates the similarity between an agent and its neighbors with regard to family structure (variable is 'hs')
  ;;the third line calculates the similarity between an agent and its neighbors with regard to citizenship (share of foreigners) (variable is 'ci')
  ;;the 'radsim' parameter represents the 'radius of similarity'
  ask turtles [set simagents-nearby count (turtles in-radius radsim) with [((ss = [ss] of myself) or (ss = [ss + 1] of myself)) and 
                                                                           ((hs = [hs] of myself) or (hs = [hs + 1] of myself) or (hs = [hs - 1] of myself)) and
                                                                           ((in = [in] of myself) or (in = [in + 1] of myself) or (in = [in - 1] of myself)) and
                                                                           ((ci = [ci] of myself))]
               set othagents-nearby count (turtles in-radius radsim) with [((ss != [ss] of myself) or (ss != [ss + 1] of myself)) and 
                                                                           ((hs != [hs] of myself) or (hs != [hs + 1] of myself) or (hs != [hs - 1] of myself)) and
                                                                           ((in != [in] of myself) or (in != [in + 1] of myself) or (in != [in - 1] of myself)) and
                                                                           ((ci != [ci] of myself))]
               set totagents-nearby simagents-nearby + othagents-nearby]
  
end


to calc-satisfaction
  ;; omega is a weight for the meaning of the spatial environment
  ;; 1 - omega is the corresponding weight for the meaning of the social environment. 
  ask turtles [set dissim-location (similar-nearby / (total-nearby + 0.001)) * omega
               set dissim-agents (simagents-nearby / (totagents-nearby + 0.001)) * (1 - omega)
               set dissim-total dissim-location + dissim-agents]
end


to search-newhome
  ask red1 [if (dissim-total < threshold) [
            move-to one-of ((patches in-radius radspace) with [(pcolor = 18) or (pcolor = 16) or (pcolor = 14) or (pcolor = 58) or (pcolor = 56) or (pcolor = 9)])
            ifelse (pcolor = 9) [
            setxy xc yc] [
            set similar-nearbynew count (patches in-radius radsim) with [(pcolor = 18) or (pcolor = 16) or (pcolor = 14) or (pcolor = 58) or (pcolor = 56)]
            set other-nearbynew count (patches in-radius radsim) with [(pcolor != 18) or (pcolor != 16) or (pcolor != 14) or (pcolor != 58) or (pcolor != 56)]]]] 
            
  ask red2 [if (dissim-total < threshold) [
            move-to one-of ((patches in-radius radspace) with [(pcolor = 16) or (pcolor = 14) or (pcolor = 12) or (pcolor = 54) or (pcolor = 52)
                                                               or (pcolor = 47) or (pcolor = 119) or (pcolor = 117) or (pcolor = 115) or (pcolor = 9)])
            ifelse (pcolor = 9) [
            setxy xc yc] [
            set similar-nearbynew count (patches in-radius radsim) with [(pcolor = 16) or (pcolor = 14) or (pcolor = 12) or (pcolor = 54) or (pcolor = 52)
                                                                         or (pcolor = 47) or (pcolor = 119) or (pcolor = 117) or (pcolor = 115)]
            set other-nearbynew count (patches in-radius radsim) with [(pcolor != 16) or (pcolor != 14) or (pcolor != 12) or (pcolor != 54) or (pcolor != 52)
                                                                       or (pcolor != 47) or (pcolor != 119) or (pcolor != 117) or (pcolor != 115)]]]] 
                                     
  ask red3 [if (dissim-total < threshold) [
            move-to one-of ((patches in-radius radspace) with [(pcolor = 16) or (pcolor = 14) or (pcolor = 12) or (pcolor = 54) or (pcolor = 52)
                                                               or (pcolor = 47) or (pcolor = 119) or (pcolor = 117) or (pcolor = 115) or (pcolor = 9)])
            ifelse (pcolor = 9) [
            setxy xc yc] [
            set similar-nearbynew count (patches in-radius radsim) with [(pcolor = 16) or (pcolor = 14) or (pcolor = 12) or (pcolor = 54) or (pcolor = 52)
                                                                         or (pcolor = 47) or (pcolor = 119) or (pcolor = 117) or (pcolor = 115)]
            set other-nearbynew count (patches in-radius radsim) with [(pcolor != 16) or (pcolor != 14) or (pcolor != 12) or (pcolor != 54) or (pcolor != 52)
                                                                       or (pcolor != 47) or (pcolor != 119) or (pcolor != 117) or (pcolor != 115)]]]]
                                                          
  ask red4 [if (dissim-total < threshold) [
            move-to one-of ((patches in-radius radspace) with [(pcolor = 12) or (pcolor = 54) or (pcolor = 52) or (pcolor = 49) or (pcolor = 119) or (pcolor = 117)
                                                                or (pcolor = 115) or (pcolor = 9)])
            ifelse (pcolor = 9) [
            setxy xc yc] [
            set similar-nearbynew count (patches in-radius radsim) with [(pcolor = 12) or (pcolor = 54) or (pcolor = 52) or (pcolor = 49) or (pcolor = 119) or (pcolor = 117)
                                                                         or (pcolor = 115)]
            set other-nearbynew count (patches in-radius radsim) with [(pcolor != 12) or (pcolor != 54) or (pcolor != 52) or (pcolor != 49) or (pcolor != 119) or (pcolor != 117)
                                                                       or (pcolor != 115)]]]]
                                                          
  ask green1 [if (dissim-total < threshold) [
              move-to one-of ((patches in-radius radspace) with [(pcolor = 58) or (pcolor = 56) or (pcolor = 18) or (pcolor = 9)])
              ifelse (pcolor = 9) [
              setxy xc yc] [
              set similar-nearbynew count (patches in-radius radsim) with [(pcolor = 58) or (pcolor = 56) or (pcolor = 18)]
              set other-nearbynew count (patches in-radius radsim) with [(pcolor != 58) or (pcolor != 56) or (pcolor != 18)]]]]       
                                                         
  ask green2 [if (dissim-total < threshold) [
              move-to one-of ((patches in-radius radspace) with [(pcolor = 58) or (pcolor = 56) or (pcolor = 18) or (pcolor = 9)])
              ifelse (pcolor = 9) [
              setxy xc yc] [
              set similar-nearbynew count (patches in-radius radsim) with [(pcolor = 58) or (pcolor = 56) or (pcolor = 18)]
              set other-nearbynew count (patches in-radius radsim) with [(pcolor != 58) or (pcolor != 56) or (pcolor != 18)]]]]
                                                               
  ask green3 [if (dissim-total < threshold) [
              move-to one-of ((patches in-radius radspace) with [(pcolor = 54) or (pcolor = 52) or (pcolor = 12) or (pcolor = 49) or (pcolor = 47)
                                                                 or (pcolor = 119) or (pcolor = 117) or (pcolor = 115) or (pcolor = 9)])
              ifelse (pcolor = 9) [
              setxy xc yc] [
              set similar-nearbynew count (patches in-radius radsim) with [(pcolor = 54) or (pcolor = 52) or (pcolor = 12) or (pcolor = 49) or (pcolor = 47)
                                                                           or (pcolor = 119) or (pcolor = 117) or (pcolor = 115)]
              set other-nearbynew count (patches in-radius radsim) with [(pcolor != 54) or (pcolor != 52) or (pcolor != 12) or (pcolor != 49) or (pcolor != 47)
                                                                         or (pcolor != 119) or (pcolor != 117) or (pcolor != 115)]]]]
                                                                           
  ask green4 [if (dissim-total < threshold) [
              move-to one-of ((patches in-radius radspace) with [(pcolor = 54) or (pcolor = 52) or (pcolor = 12) or (pcolor = 49) or (pcolor = 47)
                                                                 or (pcolor = 119) or (pcolor = 117) or (pcolor = 115) or (pcolor = 9)])
              ifelse (pcolor = 9) [
              setxy xc yc] [
              set similar-nearbynew count (patches in-radius radsim) with [(pcolor = 54) or (pcolor = 52) or (pcolor = 12) or (pcolor = 49) or (pcolor = 47)
                                                                           or (pcolor = 119) or (pcolor = 117) or (pcolor = 115)]
              set other-nearbynew count (patches in-radius radsim) with [(pcolor != 54) or (pcolor != 52) or (pcolor != 12) or (pcolor != 49) or (pcolor != 47)
                                                                         or (pcolor != 119) or (pcolor != 117) or (pcolor != 115)]]]]
                                                                                                                        
  ask yellow1 [if (dissim-total < threshold) [
               move-to one-of ((patches in-radius radspace) with [(pcolor = 49) or (pcolor = 104) or (pcolor = 9)])
               ifelse (pcolor = 9) [
               setxy xc yc] [
               set similar-nearbynew count (patches in-radius radsim) with [(pcolor = 49) or (pcolor = 104)]
               set other-nearbynew count (patches in-radius radsim) with [(pcolor != 49) or (pcolor != 104)]]]]
       
  ask yellow2 [if (dissim-total < threshold) [
               move-to one-of ((patches in-radius radspace) with [(pcolor = 12) or (pcolor = 49) or (pcolor = 47) or (pcolor = 54) or (pcolor = 52) or (pcolor = 119) or (pcolor = 9)])
               ifelse (pcolor = 9) [
               setxy xc yc] [
               set similar-nearbynew count (patches in-radius radsim) with [(pcolor = 12) or (pcolor = 49) or (pcolor = 47) or (pcolor = 54) or (pcolor = 52) or (pcolor = 119)]
               set other-nearbynew count (patches in-radius radsim) with [(pcolor != 12) or (pcolor != 49) or (pcolor != 47) or (pcolor != 54) or (pcolor != 52) or (pcolor != 119)]]]]
                                                                                                                          
  ask violet1 [if (dissim-total < threshold) [
               move-to one-of ((patches in-radius radspace) with [(pcolor = 54) or (pcolor = 52) or (pcolor = 12) or (pcolor = 49) or (pcolor = 47) or (pcolor = 119) or (pcolor = 117) or (pcolor = 9)])
               ifelse (pcolor = 9) [
               setxy xc yc] [
               set similar-nearbynew count (patches in-radius radsim) with [(pcolor = 54) or (pcolor = 52) or (pcolor = 12) or (pcolor = 49) or (pcolor = 47) or (pcolor = 119) or (pcolor = 117)]
               set other-nearbynew count (patches in-radius radsim) with [(pcolor != 54) or (pcolor != 52) or (pcolor != 12) or (pcolor != 49) or (pcolor != 47) or (pcolor != 119) or (pcolor != 117)]]]]
                                                                                                                         
  ask violet2 [if (dissim-total < threshold) [
               move-to one-of ((patches in-radius radspace) with [(pcolor = 54) or (pcolor = 52) or (pcolor = 12) or (pcolor = 49) or (pcolor = 119) or (pcolor = 117) 
                                                                  or (pcolor = 8) or (pcolor = 6) or (pcolor = 4) or (pcolor = 9)])
               ifelse (pcolor = 9) [
               setxy xc yc] [
               set similar-nearbynew count (patches in-radius radsim) with [(pcolor = 54) or (pcolor = 52) or (pcolor = 12) or (pcolor = 49) or (pcolor = 119) or (pcolor = 117) 
                                                                            or (pcolor = 8) or (pcolor = 6) or (pcolor = 4)]
               set other-nearbynew count (patches in-radius radsim) with [(pcolor != 54) or (pcolor != 52) or (pcolor != 12) or (pcolor != 49) or (pcolor != 119) or (pcolor != 117) 
                                                                          or (pcolor != 8) or (pcolor != 6) or (pcolor != 4)]]]]
               
  ask violet3 [if (dissim-total < threshold) [
               move-to one-of ((patches in-radius radspace) with [(pcolor = 54) or (pcolor = 52) or (pcolor = 12) or (pcolor = 16) or (pcolor = 14) or (pcolor = 119) or (pcolor = 117) 
                                                                  or (pcolor = 8) or (pcolor = 6) or (pcolor = 115) or (pcolor = 9)])
               ifelse (pcolor = 9) [
               setxy xc yc] [
               set similar-nearbynew count (patches in-radius radsim) with [(pcolor = 54) or (pcolor = 52) or (pcolor = 12) or (pcolor = 16) or (pcolor = 14) or (pcolor = 119) or (pcolor = 117) 
                                                                            or (pcolor = 8) or (pcolor = 6) or (pcolor = 115)]
               set other-nearbynew count (patches in-radius radsim) with [(pcolor != 54) or (pcolor != 52) or (pcolor != 12) or (pcolor != 16) or (pcolor != 14) or (pcolor != 119) or (pcolor != 117) 
                                                                          or (pcolor != 8) or (pcolor != 6) or (pcolor != 115)]]]]
                                                                                                                          
  ask gray1 [if (dissim-total < threshold) [
             move-to one-of ((patches in-radius radspace) with [(pcolor = 49) or (pcolor = 117) or (pcolor = 8) or (pcolor = 6) or (pcolor = 4) or (pcolor = 9)])
             ifelse (pcolor = 9) [
             setxy xc yc] [
             set similar-nearbynew count (patches in-radius radsim) with [(pcolor = 49) or (pcolor = 117) or (pcolor = 8) or (pcolor = 6) or (pcolor = 4)]
             set other-nearbynew count (patches in-radius radsim) with [(pcolor != 49) or (pcolor != 117) or (pcolor != 8) or (pcolor != 6) or (pcolor != 4)]]]]
                                                                                                                   
  ask gray2 [if (dissim-total < threshold) [
             move-to one-of ((patches in-radius radspace) with [(pcolor = 49) or (pcolor = 117) or (pcolor = 8) or (pcolor = 6) or (pcolor = 4) or (pcolor = 9)])
             ifelse (pcolor = 9) [
             setxy xc yc] [
             set similar-nearbynew count (patches in-radius radsim) with [(pcolor = 49) or (pcolor = 117) or (pcolor = 8) or (pcolor = 6) or (pcolor = 4)]
             set other-nearbynew count (patches in-radius radsim) with [(pcolor = 49) or (pcolor = 117) or (pcolor = 8) or (pcolor = 6) or (pcolor = 4)]]]]
                                                                                                                      
  ask gray3 [if (dissim-total < threshold) [
             move-to one-of ((patches in-radius radspace) with [(pcolor = 4) or (pcolor = 49) or (pcolor = 104) or (pcolor = 9)])
             ifelse (pcolor = 9) [
             setxy xc yc] [
             set similar-nearbynew count (patches in-radius radsim) with [(pcolor = 4) or (pcolor = 49) or (pcolor = 104)]
             set other-nearbynew count (patches in-radius radsim) with [(pcolor != 4) or (pcolor != 49) or (pcolor != 104)]]]]
                                                                                                                      
  ask blue1 [if (dissim-total < threshold) [
             move-to one-of ((patches in-radius radspace) with [(pcolor = 108) or (pcolor = 106) or (pcolor = 104) or (pcolor = 9)])
             ifelse (pcolor = 9) [
             setxy xc yc] [
             set similar-nearbynew count (patches in-radius radsim) with [(pcolor = 108) or (pcolor = 106) or (pcolor = 104)]
             set other-nearbynew count (patches in-radius radsim) with [(pcolor != 108) or (pcolor != 106) or (pcolor != 104)]]]]
                                                                                                                      
  ask blue2 [if (dissim-total < threshold) [
             move-to one-of ((patches in-radius radspace) with [(pcolor = 108) or (pcolor = 106) or (pcolor = 104) or (pcolor = 9)])
             ifelse (pcolor = 9) [
             setxy xc yc] [
             set similar-nearbynew count (patches in-radius radsim) with [(pcolor = 108) or (pcolor = 106) or (pcolor = 104)]
             set other-nearbynew count (patches in-radius radsim) with [(pcolor != 108) or (pcolor != 106) or (pcolor != 104)]]]]
                                                                                                                      
  ask blue3 [if (dissim-total < threshold) [
             move-to one-of ((patches in-radius radspace) with [(pcolor = 108) or (pcolor = 106) or (pcolor = 104) or (pcolor = 9)])
             ifelse (pcolor = 9) [
             setxy xc yc] [
             set similar-nearbynew count (patches in-radius radsim) with [(pcolor = 108) or (pcolor = 106) or (pcolor = 104)]
             set other-nearbynew count (patches in-radius radsim) with [(pcolor != 108) or (pcolor != 106) or (pcolor != 104)]]]]
end

to calc-satisfactionnew
  ask turtles [if dissim-total < threshold [set total-nearbynew similar-nearbynew + other-nearbynew
                                            set dissim-locationnew (similar-nearbynew / (total-nearbynew + 0.01)) * omega
                                            if (dissim-locationnew > dissim-location) 
                                              [set pcolor color]]] 
end

to create-newquarter
  if time = timescale [ask patches
                                     [if ((pxcor > -35) and (pxcor < -25)) and ((pycor > -40) and (pycor < -30))
                                      [if (pcolor = 106) or (pcolor = 104) [set pcolor 14 ask neighbors [set pcolor 14]]]]] 
                                      ;;a new red city quarter is emerging on a blue clustered place
  
  if time = timescale [ask patches
                                     [if ((pxcor > -40) and (pxcor < -30)) and ((pycor > 35) and (pycor < 45))
                                      [if (pcolor = 16) or (pcolor = 14) [set pcolor 47 ask neighbors [set pcolor 47]]]]] 
                                      ;;a new yellow city quarter is emerging on a red clustered place
  
  if time = timescale [ask patches
                                     [if ((pxcor > -5) and (pxcor < 5)) and ((pycor > -41) and (pycor < -34))
                                      [if (pcolor = 56) or (pcolor = 54) [set pcolor 104 ask neighbors [set pcolor 104]]]]] 
                                      ;;a new blue city quarter is emerging on a green clustered place
  
  if time = timescale [ask patches
                                     [if ((pxcor > -5) and (pxcor < 2)) and ((pycor > -5) and (pycor < 2))
                                      [if pcolor = 47 [set pcolor 117 ask neighbors [set pcolor 117]]]]] 
                                      ;;a new violet city quarter is emerging on a gray clustered place
  
  if time = timescale [ask patches
                                     [if ((pxcor > 13) and (pxcor < 23)) and ((pycor > 17) and (pycor < 23))
                                      [if (pcolor = 117) or (pcolor = 115) [set pcolor 56 ask neighbors [set pcolor 56]]]]] 
                                      ;;a new green city quarter is emerging on a violet clustered place
  
  if time = timescale [ask patches
                                     [if ((pxcor > -13) and (pxcor < -6)) and ((pycor > 24) and (pycor < 34))
                                      [if pcolor = 47 [set pcolor 6 ask neighbors [set pcolor 6]]]]] 
                                      ;;a new gray city quarter is emerging on a yellow clustered place
end

to migrate
  identify-neighborpatches
  identify-neighboragents
  calc-satisfaction
  search-newhome
  calc-satisfactionnew
  create-newquarter
  
  count-sumofpatches
  calc-patchshares
  
  plot-patchrelations
  plot-patchshares
  
  plot-acsred
  plot-acsgreen
  plot-acsyellow
  plot-acsviolet
  plot-acsgray
  plot-acsblue
  
  set time time + 1
  if time > max_time [stop]
  
  tick
end


;; diagram to show the changes of the shares of patches in absolute values
to plot-patchrelations
  set-current-plot "patch relations"
  
  set num_redpatches count patches with [(pcolor = 18) or (pcolor = 16) or (pcolor = 14) or (pcolor = 12)]
  set-current-plot-pen "red"
  plot num_redpatches
  
  set num_greenpatches count patches with [(pcolor = 58) or (pcolor = 56) or (pcolor = 54) or (pcolor = 52)]
  set-current-plot-pen "green"
  plot num_greenpatches
  
  set num_yellowpatches count patches with [(pcolor = 49) or (pcolor = 47)]
  set-current-plot-pen "yellow"
  plot num_yellowpatches
  
  set num_violetpatches count patches with [(pcolor = 119) or (pcolor = 117) or (pcolor = 115)]
  set-current-plot-pen "violet"
  plot num_violetpatches
  
  set num_graypatches count patches with [(pcolor = 8) or (pcolor = 6) or (pcolor = 4)]
  set-current-plot-pen "gray"
  plot num_graypatches
  
  set num_bluepatches count patches with [(pcolor = 108) or (pcolor = 106) or (pcolor = 104)]
  set-current-plot-pen "blue"
  plot num_bluepatches
end


;;diagram to show the number of patch clusters, depending on the size of the radius
to calc-patchcluster
  set num_radclu (radclu + radclu) + 1
  set cluster_redpatches count (patches in-radius radclu) with [(pcolor > 11) and (pcolor < 19)]
  set cluster_greenpatches count (patches in-radius radclu) with [(pcolor > 51) and (pcolor < 59)]
  set cluster_yellowpatches count (patches in-radius radclu) with [(pcolor > 41) and (pcolor < 49)]
  set cluster_violetpatches count (patches in-radius radclu) with [(pcolor > 111) and (pcolor < 119)]
  set cluster_graypatches count (patches in-radius radclu) with [(pcolor > 1) and (pcolor < 9)]
  set cluster_bluepatches count (patches in-radius radclu) with [(pcolor > 101) and (pcolor < 109)]
  
  if cluster_redpatches >= sh_value * (num_radclu * num_radclu) [set pcolor 11]
  set red_clu count patches with [pcolor = 11]
   
  
  if time > max_time [stop]
end


;; diagram to show the development of patches, standardized by the initial value
to calc-patchshares
  if (time = 0) [set redp count patches with [(pcolor = 18) or (pcolor = 16) or (pcolor = 14) or (pcolor = 12)]
                 set greenp count patches with [(pcolor = 58) or (pcolor = 56) or (pcolor = 54) or (pcolor = 52)]
                 set yellowp count patches with [(pcolor = 49) or (pcolor = 47)]
                 set violetp count patches with [(pcolor = 119) or (pcolor = 117) or (pcolor = 115)]
                 set grayp count patches with [(pcolor = 8) or (pcolor = 6) or (pcolor = 4)]
                 set bluep count patches with [(pcolor = 108) or (pcolor = 106) or (pcolor = 104)]]
end

to plot-patchshares
  set-current-plot "patch shares"
  
  set share_red (num_redpatches / (redp + 0.01)) * 100
  set-current-plot-pen "red"
  plot share_red
  
  set share_green (num_greenpatches / (greenp + 0.01)) * 100
  set-current-plot-pen "green"
  plot share_green
  
  set share_yellow (num_yellowpatches / (yellowp + 0.01)) * 100
  set-current-plot-pen "yellow"
  plot share_yellow
  
  set share_violet (num_violetpatches / (violetp + 0.01)) * 100
  set-current-plot-pen "violet"
  plot share_violet
  
  set share_gray (num_graypatches / (grayp + 0.01)) * 100
  set-current-plot-pen "gray"
  plot share_gray
  
  set share_blue (num_bluepatches / (bluep + 0.01)) * 100
  set-current-plot-pen "blue"
  plot share_blue
end


;; calculates the neighborhood of agents of the same color, hence a strong meaning of neighborhood
to calc-agentclustersame
  set cluster_redagents1 count (turtles in-radius radclu) with [(color > 11) and (color < 19)]
  set cluster_greenagents1 count (turtles in-radius radclu) with [(color > 51) and (color < 59)]
  set cluster_yellowagents1 count (turtles in-radius radclu) with [(color > 41) and (color < 49)]
  set cluster_violetagents1 count (turtles in-radius radclu) with [(color > 111) and (color < 119)]
  set cluster_grayagents1 count (turtles in-radius radclu) with [(color > 1) and (color < 9)]
  set cluster_blueagents1 count (turtles in-radius radclu) with [(color > 101) and (color < 109)]
end
  

;; calculates the neighborhood of agents of similar social properties, hence a weak meaning of neighborhood
to calc-agentclustersimilar
  set red1agents count (turtles in-radius radclu) with [(color = [color] of myself) or (color = 16) or (color = 14) or (color = 58) or (color = 56)]
  set red2agents count (turtles in-radius radclu) with [(color = [color] of myself) or (color = 14) or (color = 12) or (color = 54) or (color = 52) or (color = 47) or (color = 119) or (color = 117) or (color = 115)]
  set red3agents count (turtles in-radius radclu) with [(color = [color] of myself) or (color = 16) or (color = 12) or (color = 54) or (color = 52) or (color = 47) or (color = 119) or (color = 117) or (color = 115)]
  set red4agents count (turtles in-radius radclu) with [(color = [color] of myself) or (color = 54) or (color = 52) or (color = 49) or (color = 119) or (color = 117) or (color = 115)]
  
  set green1agents count (turtles in-radius radclu) with [(color = [color] of myself) or (color = 56) or (color = 18)]
  set green2agents count (turtles in-radius radclu) with [(color = [color] of myself) or (color = 58) or (color = 18)]
  set green3agents count (turtles in-radius radclu) with [(color = [color] of myself) or (color = 52) or (color = 12) or (color = 49) or (color = 47) or (color = 119) or (color = 117) or (color = 115)]
  set green4agents count (turtles in-radius radclu) with [(color = [color] of myself) or (color = 54) or (color = 12) or (color = 49) or (color = 47) or (color = 119) or (color = 117) or (color = 115)]
  
  set yellow1agents count (turtles in-radius radclu) with [(color = [color] of myself) or (color = 104)]
  set yellow2agents count (turtles in-radius radclu) with [(color = [color] of myself) or (color = 12) or (color = 49) or (color = 54) or (color = 52) or (color = 119)]
  
  set violet1agents count (turtles in-radius radclu) with [(color = [color] of myself) or (color = 54) or (color = 52) or (color = 12) or (color = 49) or (color = 47) or (color = 117)]
  set violet2agents count (turtles in-radius radclu) with [(color = [color] of myself) or (color = 54) or (color = 52) or (color = 12) or (color = 49) or (color = 8) or (color = 6) or (color = 4) or (color = 119)]
  set violet3agents count (turtles in-radius radclu) with [(color = [color] of myself) or (color = 54) or (color = 52) or (color = 12) or (color = 16) or (color = 14) or (color = 8) or (color = 6) or (color = 119) or (color = 117)]
  
  set gray1agents count (turtles in-radius radclu) with [(color = [color] of myself) or (color = 49) or (color = 117) or (color = 6) or (color = 4)]
  set gray2agents count (turtles in-radius radclu) with [(color = [color] of myself) or (color = 49) or (color = 117) or (color = 8) or (color = 4)]
  set gray3agents count (turtles in-radius radclu) with [(color = [color] of myself) or (color = 49) or (color = 104)]
  
  set blue1agents count (turtles in-radius radclu) with [(color = [color] of myself) or (color = 106) or (color = 104)]
  set blue2agents count (turtles in-radius radclu) with [(color = [color] of myself) or (color = 108) or (color = 104)]
  set blue3agents count (turtles in-radius radclu) with [(color = [color] of myself) or (color = 106) or (color = 108)]
  
  if time > max_time [stop] 
end

;;acs stands for agent cluster similar, followed by the agents' name  
to plot-acsred
  set-current-plot "red agents"
  
  set-current-plot-pen "red1"
  plot red1agents
  
  set-current-plot-pen "red2"
  plot red2agents
  
  set-current-plot-pen "red3"
  plot red3agents
  
  set-current-plot-pen "red4"
  plot red4agents
end

;;acs stands for agent cluster similar, followed by the agents' name  
to plot-acsgreen
  set-current-plot "green agents"
  
  set-current-plot-pen "green1"
  plot green1agents
  
  set-current-plot-pen "green2"
  plot green2agents
  
  set-current-plot-pen "green3"
  plot green3agents
  
  set-current-plot-pen "green4"
  plot green4agents
end

;;acs stands for agent cluster similar, followed by the agents' name  
to plot-acsyellow
  set-current-plot "yellow agents"
  
  set-current-plot-pen "yellow1"
  plot yellow1agents
  
  set-current-plot-pen "yellow2"
  plot yellow2agents
end

;;acs stands for agent cluster similar, followed by the agents' name  
to plot-acsviolet
  set-current-plot "violet agents"
  
  set-current-plot-pen "violet1"
  plot violet1agents
  
  set-current-plot-pen "violet2"
  plot violet2agents
  
  set-current-plot-pen "violet3"
  plot violet3agents
end

to plot-acsgray
  set-current-plot "gray agents"
  
  set-current-plot-pen "gray1"
  plot gray1agents
  
  set-current-plot-pen "gray2"
  plot gray2agents
  
  set-current-plot-pen "gray3"
  plot gray3agents
end

to plot-acsblue
  set-current-plot "blue agents"
  
  set-current-plot-pen "blue1"
  plot blue1agents
  
  set-current-plot-pen "blue2"
  plot blue2agents
  
  set-current-plot-pen "blue3"
  plot blue3agents
end


to count-sumofpatches
  set num_patches count patches
  set redsh (num_redpatches / num_patches) * 100
  set greensh (num_greenpatches / num_patches) * 100
  set yellowsh (num_yellowpatches / num_patches) * 100
  set violetsh (num_violetpatches / num_patches) * 100
  set graysh (num_graypatches / num_patches) * 100
  set bluesh (num_bluepatches / num_patches) * 100
end

@#$#@#$#@
GRAPHICS-WINDOW
476
22
1410
977
115
115
4.0
0
10
1
1
1
0
1
1
1
-115
115
-115
115
0
0
1
ticks

CC-WINDOW
5
994
1894
1089
Command Center
0

BUTTON
7
10
70
43
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
7
83
71
116
districts 
display-district
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
7
47
71
80
sprengel
display-sprengel
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
324
10
400
43
patch  sample
create-sample
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
77
10
144
43
clu 1981
display-cluster1981
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
77
49
144
82
subclu 1981
display-subcluster1981
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
149
49
217
82
subclu 1991
display-subcluster1991
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
149
10
216
43
clu 1991
display-cluster1991
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
222
11
291
44
clu 2001
display-cluster2001
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
223
49
292
82
subclu 2001
display-subcluster2001
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

SLIDER
6
144
138
177
densityRedAgentsD
densityRedAgentsD
0
100
80
1
1
NIL
HORIZONTAL

SLIDER
146
145
287
178
densityGreenAgentsD
densityGreenAgentsD
0
100
80
1
1
NIL
HORIZONTAL

SLIDER
6
180
139
213
densityRedAgentsF
densityRedAgentsF
0
50
5
1
1
NIL
HORIZONTAL

SLIDER
145
181
287
214
densityGreenAgentsF
densityGreenAgentsF
0
50
5
1
1
NIL
HORIZONTAL

SLIDER
294
181
437
214
densityYellowAgentsF
densityYellowAgentsF
0
50
5
1
1
NIL
HORIZONTAL

SLIDER
5
273
149
306
densityPurpleAgentsF
densityPurpleAgentsF
0
50
5
1
1
NIL
HORIZONTAL

SLIDER
155
273
286
306
densityGrayAgentsF
densityGrayAgentsF
0
50
5
1
1
NIL
HORIZONTAL

SLIDER
295
274
429
307
densityBlueAgentsF
densityBlueAgentsF
0
50
5
1
1
NIL
HORIZONTAL

SLIDER
295
145
436
178
densityYellowAgentsD
densityYellowAgentsD
0
100
80
1
1
NIL
HORIZONTAL

SLIDER
5
235
149
268
densityPurpleAgentsD
densityPurpleAgentsD
0
100
80
1
1
NIL
HORIZONTAL

SLIDER
155
236
286
269
densityGrayAgentsD
densityGrayAgentsD
0
100
80
1
1
NIL
HORIZONTAL

SLIDER
295
235
427
268
densityBlueAgentsD
densityBlueAgentsD
0
100
80
1
1
NIL
HORIZONTAL

BUTTON
323
48
401
81
agent sample
create-agents
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

PLOT
17
443
309
597
patch relations
time
patches
0.0
20.0
600.0
2000.0
true
false
PENS
"default" 10.0 0 -16777216 true
"red" 1.0 0 -2674135 true
"green" 1.0 0 -10899396 true
"yellow" 1.0 0 -1184463 true
"violet" 1.0 0 -8630108 true
"gray" 1.0 0 -7500403 true
"blue" 1.0 0 -13345367 true

SLIDER
13
350
105
383
radsim
radsim
1
10
3
1
1
NIL
HORIZONTAL

MONITOR
151
91
246
136
NIL
count turtles
17
1
11

SLIDER
113
351
205
384
radspace
radspace
(radsim + 1)
100
60
1
1
NIL
HORIZONTAL

TEXTBOX
39
319
98
347
radius of\nsimilarity
11
0.0
1

TEXTBOX
134
320
202
348
radius of\nsearch space
11
0.0
1

MONITOR
252
91
344
136
NIL
count patches
17
1
11

SLIDER
211
350
303
383
omega
omega
0
1
0.6
0.1
1
NIL
HORIZONTAL

TEXTBOX
227
332
309
350
spatial weight
11
0.0
1

SLIDER
310
351
402
384
threshold
threshold
0
1
0.35
0.05
1
NIL
HORIZONTAL

TEXTBOX
314
331
410
349
decision to migrate
11
0.0
1

BUTTON
355
89
434
139
NIL
migrate
T
1
T
OBSERVER
NIL
NIL
NIL
NIL

MONITOR
16
392
73
437
count
count turtles with [dissim-locationnew > dissim-location]
17
1
11

SLIDER
93
390
200
423
max_time
max_time
100
500
105
1
1
NIL
HORIZONTAL

MONITOR
81
90
138
135
NIL
time
17
1
11

SLIDER
1501
62
1593
95
radclu
radclu
1
10
2
1
1
NIL
HORIZONTAL

BUTTON
28
946
100
979
calc-clu
calc-patchcluster
NIL
1
T
TURTLE
NIL
NIL
NIL
NIL

PLOT
1555
505
1772
650
patch shares
time
percent of shares
0.0
20.0
0.0
200.0
true
false
PENS
"default" 1.0 0 -16777216 true
"red" 1.0 0 -2674135 true
"green" 1.0 0 -10899396 true
"yellow" 1.0 0 -1184463 true
"violet" 1.0 0 -8630108 true
"gray" 1.0 0 -7500403 true
"blue" 1.0 0 -13345367 true

BUTTON
217
390
303
423
calc-patchshare
calc-patchshares
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

TEXTBOX
1424
90
1850
123
___________________________________________________________________
11
0.0
1

MONITOR
1424
12
1477
57
cluRED
red_clu
17
1
11

MONITOR
1481
12
1542
57
cluGREEN
cluster_greenpatches
17
1
11

MONITOR
1740
11
1790
56
cluBLUE
cluster_bluepatches
17
1
11

MONITOR
1545
12
1610
57
cluYELLOW
cluster_yellowpatches
17
1
11

MONITOR
1615
11
1675
56
cluVIOLET
cluster_violetpatches
17
1
11

MONITOR
1680
11
1733
56
cluGRAY
cluster_graypatches
17
1
11

MONITOR
5
850
69
895
redagents
cluster_redagents1
1
1
11

PLOT
1551
108
1711
228
red agents
NIL
NIL
0.0
20.0
0.0
10.0
true
false
PENS
"default" 1.0 0 -16777216 true
"red1" 1.0 0 -2674135 true
"red2" 1.0 0 -10899396 true
"red3" 1.0 0 -13345367 true
"red4" 1.0 2 -1184463 true

BUTTON
322
451
426
484
agent cluster
calc-agentclustersimilar
T
1
T
TURTLE
NIL
NIL
NIL
NIL

MONITOR
6
763
56
808
NIL
redsh
2
1
11

MONITOR
59
763
113
808
NIL
greensh
2
1
11

MONITOR
116
764
168
809
NIL
yellowsh
2
1
11

MONITOR
171
764
221
809
NIL
violetsh
2
1
11

MONITOR
225
763
275
808
NIL
graysh
2
1
11

MONITOR
278
764
328
809
NIL
bluesh
2
1
11

TEXTBOX
1797
14
1867
32
patch clusters
11
0.0
1

MONITOR
374
851
442
896
blueagents
cluster_blueagents1
1
1
11

MONITOR
148
850
224
895
yellowagents
cluster_yellowagents1
17
1
11

MONITOR
73
850
145
895
greenagents
cluster_greenagents1
1
1
11

MONITOR
228
850
300
895
violetagents
cluster_violetagents1
1
1
11

MONITOR
303
850
370
895
grayagents
cluster_grayagents1
1
1
11

PLOT
1722
375
1882
495
blue agents
NIL
NIL
0.0
20.0
0.0
10.0
true
false
PENS
"default" 1.0 0 -16777216 true
"blue1" 1.0 0 -2674135 true
"blue2" 1.0 0 -10899396 true
"blue3" 1.0 0 -13345367 true

TEXTBOX
31
306
410
348
______________________________________________________________
11
0.0
1

TEXTBOX
341
771
419
799
share of patches\n
11
0.0
1

TEXTBOX
105
830
301
858
number of agents of same/similar type
11
0.0
1

BUTTON
105
946
193
979
calc-agentshare
calc-agentclustersame
NIL
1
T
TURTLE
NIL
NIL
NIL
NIL

PLOT
1724
107
1884
227
green agents
NIL
NIL
0.0
10.0
0.0
10.0
true
false
PENS
"default" 1.0 0 -16777216 true
"green1" 1.0 0 -2674135 true
"green2" 1.0 0 -10899396 true
"green3" 1.0 0 -13345367 true
"green4" 1.0 0 -1184463 true

PLOT
1553
243
1713
363
yellow agents
NIL
NIL
0.0
10.0
0.0
10.0
true
false
PENS
"default" 1.0 0 -16777216 true
"yellow1" 1.0 0 -2674135 true
"yellow2" 1.0 0 -10899396 true

PLOT
1725
241
1885
361
violet agents
NIL
NIL
0.0
10.0
0.0
10.0
true
false
PENS
"default" 1.0 0 -16777216 true
"violet1" 1.0 0 -2674135 true
"violet2" 1.0 0 -10899396 true
"violet3" 1.0 0 -13345367 true

PLOT
1553
375
1713
495
gray agents
NIL
NIL
0.0
10.0
0.0
10.0
true
false
PENS
"default" 1.0 0 -16777216 true
"gray1" 1.0 0 -2674135 true
"gray2" 1.0 0 -10899396 true
"gray3" 1.0 0 -13345367 true

SLIDER
197
947
289
980
sh_value
sh_value
0
1
0.5
0.1
1
NIL
HORIZONTAL

SLIDER
326
394
418
427
timescale
timescale
5
100
5
1
1
NIL
HORIZONTAL

@#$#@#$#@
WHAT IS IT?
-----------
This section could give a general understanding of what the model is trying to show or explain.


HOW IT WORKS
------------
This section could explain what rules the agents use to create the overall behavior of the model.


HOW TO USE IT
-------------
This section could explain how to use the model, including a description of each of the items in the interface tab.


THINGS TO NOTICE
----------------
This section could give some ideas of things for the user to notice while running the model.


THINGS TO TRY
-------------
This section could give some ideas of things for the user to try to do (move sliders, switches, etc.) with the model.


EXTENDING THE MODEL
-------------------
This section could give some ideas of things to add or change in the procedures tab to make the model more complicated, detailed, accurate, etc.


NETLOGO FEATURES
----------------
This section could point out any especially interesting or unusual features of NetLogo that the model makes use of, particularly in the Procedures tab.  It might also point out places where workarounds were needed because of missing features.


RELATED MODELS
--------------
This section could give the names of models in the NetLogo Models Library or elsewhere which are of related interest.


CREDITS AND REFERENCES
----------------------
This section could contain a reference to the model's URL on the web if it has one, as well as any other necessary credits or references.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 4.0.2
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
